<!DOCTYPE html>
<html>
  <head>
    <meta name="viewport" content="initial-scale=1.0, user-scalable=no">
    <meta charset="utf-8">
    <title>County Overlay</title>
    <link rel="stylesheet" href="CQX_StyleSheet-new.css" type="text/css" />

    <style>
      html, body, #map-canvas {
        height: 100%;
        margin: 0px;
        padding: 0px
      }
      html, body, #countySelection{width: 100%; height: 100%}
    </style>


    <script src="https://maps.googleapis.com/maps/api/js?v=3.exp"></script>

    <script language="javascript" type="text/javascript">

    var map;
    var infoWindow;
    var theCountyMarkers = new Array();
    var theCountyValues = new Array();
    var cqxUrl = "http://www.no5w.com";


    var stateFullName = "Georgia";
    var qsoPartyUrl = "http://georgiaqsoparty.org/";
    var overlayUrl = "http://www.no5w.com/OverlayGeorgiaRev3.kml";

    /*-----------------------------------------------------------------------------------------------------
     PromoControl: constructor for the QSO Party promo control to add to the map
     -----------------------------------------------------------------------------------------------------*/
    function PromoControl(controlDiv, map) {

      // Set CSS styles for the DIV containing the control
      // Setting padding to 5 px will offset the control
      // from the edge of the map.
      controlDiv.style.padding = '5px';

      // Set CSS for the control border.
      var controlUI = document.createElement('div');
      controlUI.style.backgroundColor = 'white';
      controlUI.style.borderStyle = 'solid';
      controlUI.style.borderWidth = '1px';
      controlUI.style.cursor = 'pointer';
      controlUI.style.textAlign = 'center';
      controlUI.title = 'Click to access QSO Party home page';
      controlDiv.appendChild(controlUI);

      // Set CSS for the control interior.
      var controlText = document.createElement('div');
      controlText.style.fontFamily = 'Arial,sans-serif';
      controlText.style.fontSize = '24px';
      controlText.style.paddingLeft = '3px';
      controlText.style.paddingRight = '3px';
      controlText.innerHTML = '<strong>' + String(stateFullName) + '</strong>';
      controlUI.appendChild(controlText);

      google.maps.event.addDomListener(controlUI, 'click', function() {
        document.location.assign(String(qsoPartyUrl));
      });
    }//PromoControl constructor

    /*-----------------------------------------------------------------------------------------------------
     CQXPromoControl: constructor for the CQ/X promo control to add to the map
     -----------------------------------------------------------------------------------------------------*/
    function CQXPromoControl(controlDiv, map) {

      // Set CSS styles for the DIV containing the control
      // Setting padding to 5 px will offset the control
      // from the edge of the map.
      controlDiv.style.padding = '5px';

      // Set CSS for the control border.
      var controlUI = document.createElement('div');
      controlUI.style.backgroundColor = 'white';
      controlUI.style.borderStyle = 'solid';
      controlUI.style.borderWidth = '1px';
      controlUI.style.cursor = 'pointer';
      controlUI.style.textAlign = 'center';
      controlUI.title = 'Click to access CQ/X home page';
      controlDiv.appendChild(controlUI);

      // Set CSS for the control interior.
      var controlText = document.createElement('div');
      controlText.style.fontFamily = 'Arial,sans-serif';
      controlText.style.fontSize = '12px';
      controlText.style.paddingLeft = '3px';
      controlText.style.paddingRight = '3px';
      controlText.innerHTML = '<strong>' + String("CQ/X de NO5W") + '</strong>';
      controlUI.appendChild(controlText);

      google.maps.event.addDomListener(controlUI, 'click', function() {
        document.location.assign(String(cqxUrl));
      });
    }//CQXPromoControl constructor

/*-----------------------------------------------------------------------------------------------------
 addMarker: function for adding a county marker
-----------------------------------------------------------------------------------------------------*/
function addMarker(lat, lon, desc, aval) {
  var markerLatLng = new google.maps.LatLng(lat, lon);

  var markerOptions = {
    flat: true,
    map: map,
    optimized: false,
    position: markerLatLng,
    visible: true,
    title: desc
    };
  var marker = new google.maps.Marker(markerOptions);
  theCountyMarkers.push(marker);
  theCountyValues.push(aval);

  }//addMarker

/*-----------------------------------------------------------------------------------------------------
 removeMarkers: function for removing all of the current markers
 -----------------------------------------------------------------------------------------------------*/
function removeMarkers() {
  for(var i=0;i<theCountyMarkers.length;i++) theCountyMarkers[i].setMap(null);
  }//removeMarkers     

/*-----------------------------------------------------------------------------------------------------
 populateCountySelection: function for building the county selection
 -----------------------------------------------------------------------------------------------------*/
function populateCountySelection() {
  var countySelection = document.getElementById("countySelection");
          
  countySelection.options.length = 0;
  theCountyMarkers.length = 0;
  theCountyValues.length = 0;

  countySelection.options[0] = new Option("Appling", "appl");
  countySelection.options[1] = new Option("Atkinson", "atkn");
  countySelection.options[2] = new Option("Bacon", "bacn");
  countySelection.options[3] = new Option("Baker", "bakr");
  countySelection.options[4] = new Option("Baldwin", "bald");
  countySelection.options[5] = new Option("Banks", "bank");
  countySelection.options[6] = new Option("Barrow", "barr");
  countySelection.options[7] = new Option("Bartow", "bart");
  countySelection.options[8] = new Option("BenHill", "benh");
  countySelection.options[9] = new Option("Berrien", "berr");
  countySelection.options[10] = new Option("Bibb", "bibb");
  countySelection.options[11] = new Option("Bleckley", "blec");
  countySelection.options[12] = new Option("Brantley", "bran");
  countySelection.options[13] = new Option("Brooks", "brok");
  countySelection.options[14] = new Option("Bryan", "bryn");
  countySelection.options[15] = new Option("Bulloch", "bull");
  countySelection.options[16] = new Option("Burke", "burk");
  countySelection.options[17] = new Option("Butts", "butt");
  countySelection.options[18] = new Option("Calhoun", "calh");
  countySelection.options[19] = new Option("Camden", "cmdn");
  countySelection.options[20] = new Option("Candler", "cand");
  countySelection.options[21] = new Option("Carroll", "carr");
  countySelection.options[22] = new Option("Catoosa", "cato");
  countySelection.options[23] = new Option("Charlton", "char");
  countySelection.options[24] = new Option("Chatham", "chtm");
  countySelection.options[25] = new Option("Chattahoochee", "chat");
  countySelection.options[26] = new Option("Chattooga", "chga");
  countySelection.options[27] = new Option("Cherokee", "cher");
  countySelection.options[28] = new Option("Clarke", "clke");
  countySelection.options[29] = new Option("Clay", "clay");
  countySelection.options[30] = new Option("Clayton", "cltn");
  countySelection.options[31] = new Option("Clinch", "clch");
  countySelection.options[32] = new Option("Cobb", "cobb");
  countySelection.options[33] = new Option("Coffee", "coff");
  countySelection.options[34] = new Option("Colquitt", "colq");
  countySelection.options[35] = new Option("Columbia", "colu");
  countySelection.options[36] = new Option("Cook", "cook");
  countySelection.options[37] = new Option("Coweta", "cowe");
  countySelection.options[38] = new Option("Crawford", "craw");
  countySelection.options[39] = new Option("Crisp", "cris");
  countySelection.options[40] = new Option("Dade", "dade");
  countySelection.options[41] = new Option("Dawson", "daws");
  countySelection.options[42] = new Option("Decatur", "deca");
  countySelection.options[43] = new Option("DeKalb", "dklb");
  countySelection.options[44] = new Option("Dodge", "dodg");
  countySelection.options[45] = new Option("Dooly", "dool");
  countySelection.options[46] = new Option("Dougherty", "dhty");
  countySelection.options[47] = new Option("Douglas", "doug");
  countySelection.options[48] = new Option("Early", "earl");
  countySelection.options[49] = new Option("Echols", "echo");
  countySelection.options[50] = new Option("Effingham", "effi");
  countySelection.options[51] = new Option("Elbert", "elbe");
  countySelection.options[52] = new Option("Emanuel", "eman");
  countySelection.options[53] = new Option("Evans", "evan");
  countySelection.options[54] = new Option("Fannin", "fann");
  countySelection.options[55] = new Option("Fayette", "faye");
  countySelection.options[56] = new Option("Floyd", "floy");
  countySelection.options[57] = new Option("Forsyth", "fors");
  countySelection.options[58] = new Option("Franklin", "fran");
  countySelection.options[59] = new Option("Fulton", "fult");
  countySelection.options[60] = new Option("Gilmer", "gilm");
  countySelection.options[61] = new Option("Glascock", "glas");
  countySelection.options[62] = new Option("Glynn", "glyn");
  countySelection.options[63] = new Option("Gordon", "gord");
  countySelection.options[64] = new Option("Grady", "grad");
  countySelection.options[65] = new Option("Greene", "gree");
  countySelection.options[66] = new Option("Gwinnett", "gwin");
  countySelection.options[67] = new Option("Habersham", "habe");
  countySelection.options[68] = new Option("Hall", "hall");
  countySelection.options[69] = new Option("Hancock", "hanc");
  countySelection.options[70] = new Option("Haralson", "hara");
  countySelection.options[71] = new Option("Harris", "harr");
  countySelection.options[72] = new Option("Hart", "hart");
  countySelection.options[73] = new Option("Heard", "hear");
  countySelection.options[74] = new Option("Henry", "hnry");
  countySelection.options[75] = new Option("Houston", "hous");
  countySelection.options[76] = new Option("Irwin", "irwi");
  countySelection.options[77] = new Option("Jackson", "jack");
  countySelection.options[78] = new Option("Jasper", "jasp");
  countySelection.options[79] = new Option("JeffDavis", "jfda");
  countySelection.options[80] = new Option("Jefferson", "jeff");
  countySelection.options[81] = new Option("Jenkins", "jenk");
  countySelection.options[82] = new Option("Johnson", "john");
  countySelection.options[83] = new Option("Jones", "jone");
  countySelection.options[84] = new Option("Lamar", "lama");
  countySelection.options[85] = new Option("Lanier", "lani");
  countySelection.options[86] = new Option("Laurens", "laur");
  countySelection.options[87] = new Option("Lee", "lee");
  countySelection.options[88] = new Option("Liberty", "libe");
  countySelection.options[89] = new Option("Lincoln", "linc");
  countySelection.options[90] = new Option("Long", "long");
  countySelection.options[91] = new Option("Lowndes", "lown");
  countySelection.options[92] = new Option("Lumpkin", "lump");
  countySelection.options[93] = new Option("Macon", "maco");
  countySelection.options[94] = new Option("Madison", "madi");
  countySelection.options[95] = new Option("Marion", "mari");
  countySelection.options[96] = new Option("McDuffie", "mcdu");
  countySelection.options[97] = new Option("McIntosh", "mcin");
  countySelection.options[98] = new Option("Meriwether", "meri");
  countySelection.options[99] = new Option("Miller", "mill");
  countySelection.options[100] = new Option("Mitchell", "mitc");
  countySelection.options[101] = new Option("Monroe", "mnro");
  countySelection.options[102] = new Option("Montgomery", "mont");
  countySelection.options[103] = new Option("Morgan", "morg");
  countySelection.options[104] = new Option("Murray", "murr");
  countySelection.options[105] = new Option("Muscogee", "musc");
  countySelection.options[106] = new Option("Newton", "newt");
  countySelection.options[107] = new Option("Oconee", "ocon");
  countySelection.options[108] = new Option("Oglethorpe", "ogle");
  countySelection.options[109] = new Option("Paulding", "paul");
  countySelection.options[110] = new Option("Peach", "peac");
  countySelection.options[111] = new Option("Pickens", "pick");
  countySelection.options[112] = new Option("Pierce", "pier");
  countySelection.options[113] = new Option("Pike", "pike");
  countySelection.options[114] = new Option("Polk", "polk");
  countySelection.options[115] = new Option("Pulaski", "pula");
  countySelection.options[116] = new Option("Putnam", "putn");
  countySelection.options[117] = new Option("Quitman", "quit");
  countySelection.options[118] = new Option("Rabun", "rabu");
  countySelection.options[119] = new Option("Randolph", "rand");
  countySelection.options[120] = new Option("Richmond", "rich");
  countySelection.options[121] = new Option("Rockdale", "rock");
  countySelection.options[122] = new Option("Schley", "schl");
  countySelection.options[123] = new Option("Screven", "scre");
  countySelection.options[124] = new Option("Seminole", "semi");
  countySelection.options[125] = new Option("Spalding", "spal");
  countySelection.options[126] = new Option("Stephens", "step");
  countySelection.options[127] = new Option("Stewart", "stwt");
  countySelection.options[128] = new Option("Sumter", "sumt");
  countySelection.options[129] = new Option("Talbot", "tlbt");
  countySelection.options[130] = new Option("Taliaferro", "tali");
  countySelection.options[131] = new Option("Tattnall", "tatt");
  countySelection.options[132] = new Option("Taylor", "tayl");
  countySelection.options[133] = new Option("Telfair", "telf");
  countySelection.options[134] = new Option("Terrell", "terr");
  countySelection.options[135] = new Option("Thomas", "thom");
  countySelection.options[136] = new Option("Tift", "tift");
  countySelection.options[137] = new Option("Toombs", "toom");
  countySelection.options[138] = new Option("Towns", "town");
  countySelection.options[139] = new Option("Treutlen", "treu");
  countySelection.options[140] = new Option("Troup", "trou");
  countySelection.options[141] = new Option("Turner", "turn");
  countySelection.options[142] = new Option("Twiggs", "twig");
  countySelection.options[143] = new Option("Union", "unio");
  countySelection.options[144] = new Option("Upson", "upso");
  countySelection.options[145] = new Option("Walker", "wlkr");
  countySelection.options[146] = new Option("Walton", "walt");
  countySelection.options[147] = new Option("Ware", "ware");
  countySelection.options[148] = new Option("Warren", "warr");
  countySelection.options[149] = new Option("Washington", "wash");
  countySelection.options[150] = new Option("Wayne", "wayn");
  countySelection.options[151] = new Option("Webster", "webs");
  countySelection.options[152] = new Option("Wheeler", "whee");
  countySelection.options[153] = new Option("White", "whit");
  countySelection.options[154] = new Option("Whitfield", "wfld");
  countySelection.options[155] = new Option("Wilcox", "wcox");
  countySelection.options[156] = new Option("Wilkes", "wilk");
  countySelection.options[157] = new Option("Wilkinson", "wksn");
  countySelection.options[158] = new Option("Worth", "wort");
  addMarker(31.71780000, -82.29970000, "Appling", "appl");
  addMarker(31.30180000, -82.88500000, "Atkinson", "atkn");
  addMarker(31.56380000, -82.42760000, "Bacon", "bacn");
  addMarker(31.26660000, -84.39130000, "Baker", "bakr");
  addMarker(33.05830000, -83.23660000, "Baldwin", "bald");
  addMarker(34.34470000, -83.50390000, "Banks", "bank");
  addMarker(34.01180000, -83.70330000, "Barrow", "barr");
  addMarker(34.24410000, -84.84570000, "Bartow", "bart");
  addMarker(31.75180000, -83.24010000, "BenHill", "benh");
  addMarker(31.25070000, -83.23640000, "Berrien", "berr");
  addMarker(32.80760000, -83.69130000, "Bibb", "bibb");
  addMarker(32.42830000, -83.31850000, "Bleckley", "blec");
  addMarker(31.19200000, -82.00810000, "Brantley", "bran");
  addMarker(30.85810000, -83.54540000, "Brooks", "brok");
  addMarker(31.98370000, -81.46020000, "Bryan", "bryn");
  addMarker(32.40290000, -81.73230000, "Bulloch", "bull");
  addMarker(33.05050000, -81.92950000, "Burke", "burk");
  addMarker(33.31580000, -83.96570000, "Butts", "butt");
  addMarker(31.53580000, -84.62030000, "Calhoun", "calh");
  addMarker(30.93950000, -81.67010000, "Camden", "cmdn");
  addMarker(32.41430000, -82.08670000, "Candler", "cand");
  addMarker(33.61890000, -85.07360000, "Carroll", "carr");
  addMarker(34.87760000, -85.12240000, "Catoosa", "cato");
  addMarker(30.71680000, -82.15630000, "Charlton", "char");
  addMarker(31.97930000, -81.11610000, "Chatham", "chtm");
  addMarker(32.37800000, -84.82270000, "Chattahoochee", "chat");
  addMarker(34.43770000, -85.31750000, "Chattooga", "chga");
  addMarker(34.24290000, -84.45830000, "Cherokee", "cher");
  addMarker(33.94430000, -83.38910000, "Clarke", "clke");
  addMarker(31.63320000, -84.97000000, "Clay", "clay");
  addMarker(33.50070000, -84.35130000, "Clayton", "cltn");
  addMarker(30.88320000, -82.69510000, "Clinch", "clch");
  addMarker(33.91250000, -84.55720000, "Cobb", "cobb");
  addMarker(31.59000000, -82.87370000, "Coffee", "coff");
  addMarker(31.18040000, -83.76000000, "Colquitt", "colq");
  addMarker(33.52760000, -82.23550000, "Columbia", "colu");
  addMarker(31.18880000, -83.42830000, "Cook", "cook");
  addMarker(33.35140000, -84.75610000, "Coweta", "cowe");
  addMarker(32.69350000, -83.95190000, "Crawford", "craw");
  addMarker(31.91710000, -83.78540000, "Crisp", "cris");
  addMarker(34.80430000, -85.48450000, "Dade", "dade");
  addMarker(34.47590000, -84.15190000, "Dawson", "daws");
  addMarker(30.88470000, -84.62370000, "Decatur", "deca");
  addMarker(33.79250000, -84.18700000, "DeKalb", "dklb");
  addMarker(32.17640000, -83.12290000, "Dodge", "dodg");
  addMarker(32.16010000, -83.81960000, "Dooly", "dool");
  addMarker(31.54310000, -84.21960000, "Dougherty", "dhty");
  addMarker(33.68970000, -84.74460000, "Douglas", "doug");
  addMarker(31.29560000, -84.87110000, "Early", "earl");
  addMarker(30.73220000, -82.85780000, "Echols", "echo");
  addMarker(32.34570000, -81.33360000, "Effingham", "effi");
  addMarker(34.12230000, -82.83390000, "Elbert", "elbe");
  addMarker(32.56650000, -82.32450000, "Emanuel", "eman");
  addMarker(32.16340000, -81.87190000, "Evans", "evan");
  addMarker(34.79550000, -84.35790000, "Fannin", "fann");
  addMarker(33.40380000, -84.50440000, "Fayette", "faye");
  addMarker(34.33330000, -85.23370000, "Floyd", "floy");
  addMarker(34.19300000, -84.09270000, "Forsyth", "fors");
  addMarker(34.38040000, -83.22440000, "Franklin", "fran");
  addMarker(33.84440000, -84.47410000, "Fulton", "fult");
  addMarker(34.70200000, -84.42530000, "Gilmer", "gilm");
  addMarker(33.22310000, -82.59390000, "Glascock", "glas");
  addMarker(31.23320000, -81.52620000, "Glynn", "glyn");
  addMarker(34.50920000, -84.87830000, "Gordon", "gord");
  addMarker(30.87750000, -84.22680000, "Grady", "grad");
  addMarker(33.55840000, -83.17830000, "Greene", "gree");
  addMarker(33.96040000, -84.03790000, "Gwinnett", "gwin");
  addMarker(34.62940000, -83.51050000, "Habersham", "habe");
  addMarker(34.30620000, -83.83890000, "Hall", "hall");
  addMarker(33.25950000, -83.01070000, "Hancock", "hanc");
  addMarker(33.77920000, -85.21160000, "Haralson", "hara");
  addMarker(32.72790000, -84.93390000, "Harris", "harr");
  addMarker(34.35320000, -82.94460000, "Hart", "hart");
  addMarker(33.27880000, -85.11650000, "Heard", "hear");
  addMarker(33.47230000, -84.13900000, "Henry", "hnry");
  addMarker(32.48740000, -83.66960000, "Houston", "hous");
  addMarker(31.62090000, -83.24980000, "Irwin", "irwi");
  addMarker(34.13060000, -83.58740000, "Jackson", "jack");
  addMarker(33.32900000, -83.69850000, "Jasper", "jasp");
  addMarker(31.82160000, -82.63360000, "JeffDavis", "jfda");
  addMarker(33.03740000, -82.44710000, "Jefferson", "jeff");
  addMarker(32.78040000, -81.95780000, "Jenkins", "jenk");
  addMarker(32.66590000, -82.69560000, "Johnson", "john");
  addMarker(33.01360000, -83.58730000, "Jones", "jone");
  addMarker(33.06720000, -84.15550000, "Lamar", "lama");
  addMarker(31.01550000, -83.08380000, "Lanier", "lani");
  addMarker(32.43150000, -82.92990000, "Laurens", "laur");
  addMarker(31.76910000, -84.13050000, "Lee", "lee");
  addMarker(31.82410000, -81.47770000, "Liberty", "libe");
  addMarker(33.81080000, -82.43240000, "Lincoln", "linc");
  addMarker(31.77680000, -81.73680000, "Long", "long");
  addMarker(30.82800000, -83.25220000, "Lowndes", "lown");
  addMarker(34.57980000, -84.01260000, "Lumpkin", "lump");
  addMarker(32.35070000, -84.04630000, "Macon", "maco");
  addMarker(34.13630000, -83.18950000, "Madison", "madi");
  addMarker(32.34810000, -84.52440000, "Marion", "mari");
  addMarker(33.48550000, -82.47190000, "McDuffie", "mcdu");
  addMarker(31.49500000, -81.42280000, "McIntosh", "mcin");
  addMarker(33.03810000, -84.67750000, "Meriwether", "meri");
  addMarker(31.16380000, -84.72980000, "Miller", "mill");
  addMarker(31.26050000, -84.25300000, "Mitchell", "mitc");
  addMarker(33.02550000, -83.91520000, "Monroe", "mnro");
  addMarker(32.15120000, -82.53270000, "Montgomery", "mont");
  addMarker(33.62610000, -83.47840000, "Morgan", "morg");
  addMarker(34.78580000, -84.76350000, "Murray", "murr");
  addMarker(32.49100000, -84.87400000, "Muscogee", "musc");
  addMarker(33.55630000, -83.86490000, "Newton", "newt");
  addMarker(33.83220000, -83.46110000, "Oconee", "ocon");
  addMarker(33.86920000, -83.04300000, "Oglethorpe", "ogle");
  addMarker(33.92810000, -84.88610000, "Paulding", "paul");
  addMarker(32.56580000, -83.85960000, "Peach", "peac");
  addMarker(34.46850000, -84.45550000, "Pickens", "pick");
  addMarker(31.36650000, -82.20660000, "Pierce", "pier");
  addMarker(33.08880000, -84.39300000, "Pike", "pike");
  addMarker(33.99990000, -85.17230000, "Polk", "polk");
  addMarker(32.25280000, -83.45350000, "Pulaski", "pula");
  addMarker(33.32550000, -83.34440000, "Putnam", "putn");
  addMarker(31.88140000, -85.02450000, "Quitman", "quit");
  addMarker(34.85840000, -83.38300000, "Rabun", "rabu");
  addMarker(31.77520000, -84.74720000, "Randolph", "rand");
  addMarker(33.38600000, -82.09600000, "Richmond", "rich");
  addMarker(33.65610000, -84.04890000, "Rockdale", "rock");
  addMarker(32.29330000, -84.30590000, "Schley", "schl");
  addMarker(32.76740000, -81.62870000, "Screven", "scre");
  addMarker(30.89350000, -84.87970000, "Seminole", "semi");
  addMarker(33.26570000, -84.29900000, "Spalding", "spal");
  addMarker(34.57370000, -83.28170000, "Stephens", "step");
  addMarker(32.07660000, -84.84960000, "Stewart", "stwt");
  addMarker(32.05130000, -84.18160000, "Sumter", "sumt");
  addMarker(32.70110000, -84.49490000, "Talbot", "tlbt");
  addMarker(33.58570000, -82.84700000, "Taliaferro", "tali");
  addMarker(32.05070000, -81.99830000, "Tattnall", "tatt");
  addMarker(32.55980000, -84.22770000, "Taylor", "tayl");
  addMarker(31.96400000, -82.92590000, "Telfair", "telf");
  addMarker(31.79430000, -84.43080000, "Terrell", "terr");
  addMarker(30.86820000, -83.92780000, "Thomas", "thom");
  addMarker(31.46200000, -83.50260000, "Tift", "tift");
  addMarker(32.13290000, -82.33220000, "Toombs", "toom");
  addMarker(34.89150000, -83.74660000, "Towns", "town");
  addMarker(32.40310000, -82.56530000, "Treutlen", "treu");
  addMarker(33.04660000, -85.04900000, "Troup", "trou");
  addMarker(31.70970000, -83.62760000, "Turner", "turn");
  addMarker(32.67530000, -83.41910000, "Twiggs", "twig");
  addMarker(34.81400000, -83.97980000, "Union", "unio");
  addMarker(32.84490000, -84.32830000, "Upson", "upso");
  addMarker(34.78350000, -85.29230000, "Walker", "wlkr");
  addMarker(33.76340000, -83.74400000, "Walton", "walt");
  addMarker(31.01890000, -82.41650000, "Ware", "ware");
  addMarker(33.43240000, -82.62520000, "Warren", "warr");
  addMarker(32.99770000, -82.79220000, "Washington", "wash");
  addMarker(31.57820000, -81.88020000, "Wayne", "wayn");
  addMarker(32.07610000, -84.54350000, "Webster", "webs");
  addMarker(32.11410000, -82.73960000, "Wheeler", "whee");
  addMarker(34.65250000, -83.74680000, "White", "whit");
  addMarker(34.80190000, -84.98970000, "Whitfield", "wfld");
  addMarker(31.98900000, -83.39460000, "Wilcox", "wcox");
  addMarker(33.79360000, -82.73340000, "Wilkes", "wilk");
  addMarker(32.79650000, -83.17680000, "Wilkinson", "wksn");
  addMarker(31.58390000, -83.84120000, "Worth", "wort");

  countySelection.selectedIndex = 0;
  }

//----------------------------------------------------------------------------------------------------

function initialize() {

  populateCountySelection();

  var mapOptions = {
    zoom: 11
    };

  map = new google.maps.Map(document.getElementById('map-canvas'), mapOptions);

  var stateLayer = new google.maps.KmlLayer({url: overlayUrl, suppressInfoWindows: true});
  stateLayer.setMap(map);

  // Add a listener for the click event.
  google.maps.event.addListener(stateLayer, 'click', showLatLon);

  infoWindow = new google.maps.InfoWindow();

  var promoControlDiv = document.createElement('div');
  var promoControl = new PromoControl(promoControlDiv, map);

  promoControlDiv.index = 1;
  map.controls[google.maps.ControlPosition.TOP_CENTER].push(promoControlDiv);

  var promoCQXControlDiv = document.createElement('div');
  var promoCQXControl = new CQXPromoControl(promoCQXControlDiv, map);

  promoCQXControlDiv.index = 2;
  map.controls[google.maps.ControlPosition.TOP_RIGHT].push(promoCQXControlDiv);

  }

/*-----------------------------------------------------------------------------------------------------
 changeCounty: function processing a county change from the countySelection 
 -----------------------------------------------------------------------------------------------------*/
function changeCounty() {
  removeMarkers();
  var acounty = encodeURIComponent(document.getElementById("countySelection").value);
  var iMark = -1;
  for(i=0;i<theCountyValues.length;i++) {
    if(theCountyValues[i] != acounty) continue;
    iMark = i;
    break;
    }
  if(iMark < 0) return;
  map.setCenter(theCountyMarkers[iMark].getPosition());
  theCountyMarkers[iMark].setMap(map);
  }//function changeCounty

function catchEvent(eventObj, event, eventHandler) {
  if(eventObj.addEventListener) {
    eventObj.addEventListener(event, eventHandler, false);
    }
  else if(eventObj.attachEvent) {
    event = "on" + event;
    eventObj.attachEvent(event, eventHandler);
    }
  }//catchEvent

/*-----------------------------------------------------------------------------------------------------
 set up event handlers when the window loads 
 -----------------------------------------------------------------------------------------------------*/
catchEvent(window, "load", function() {
  document.getElementById("countySelection").onchange=changeCounty;
  });

function showLatLon(event) {

  var nameStr = event.featureData.name; //FullName=Abbrev Num
  var arrayOne = nameStr.split("=");
  var arrayTwo = arrayOne[1].split(" ");

  var contentString = '<b>Clicked on Location</b>' + '<br>' +
                    '<b>LatLon: </b>' + event.latLng.lat() + ',' + event.latLng.lng() + '<br>' +
                    '<b>In County: </b>' + arrayOne[0] + '(' + arrayTwo[0] + ')';

  // Replace the info window's content and position.
  infoWindow.setContent(contentString);
  infoWindow.setPosition(event.latLng);

  infoWindow.open(map);
  }

google.maps.event.addDomListener(window, 'load', initialize);


    </script>
  </head>

  <body>

    <table style="width: 1000px;">
      <tbody>
        <tr style="vertical-align: top;">

          <td>
          <form>
            <div class="elem" style = "width: 120px; height: 700px; margin: 0; padding: 0; overflow:auto;">
              <select id="countySelection" name="county" size='43'>
                <option> </option>
              </select>
            </div>
          </form>
          </td>

          <td>
            <div id="map-canvas" style="width: 880px; height: 700px;"></div>
          </td>
        </tr>
      </tbody>
    </table>

  </body>


</html>

